@@ -17,8 +17,12 @@ from djanticapi.utils import import_object
 
 
 class BaseAPIView(View):
-    authentication_cls_list = ('djanticapi.authentication.SessionAuthentication', 'djanticapi.authentication.BasicAuthentication',)
-    permission_cls_list = ('djanticapi.permissions.AllowAny',)
+    authentication_classes = (
+        'djanticapi.authentication.SessionAuthentication',
+        'djanticapi.authentication.BasicAuthentication',
+        'djanticapi.jwt.authentication.JWTAuthentication',
+    )
+    permission_classes = ('djanticapi.permissions.AllowAny',)
 
     @classmethod
     def as_view(cls: Any, **initkwargs: Any) -> Callable[..., HttpResponse]:
@@ -104,8 +108,8 @@ class BaseAPIView(View):
 
     @property
     def permissions(self) -> List['BasePermission']:
-        return [import_object(p)() for p in self.permission_cls_list]
+        return [import_object(p)() for p in self.permission_classes]
 
     @property
     def authenticators(self) -> List['BaseAuthentication']:
-        return [import_object(a)() for a in self.authentication_cls_list]
+        return [import_object(a)() for a in self.authentication_classes]
